.. _androidinstall:

Installation on Android
=======================

.. note::

    The Android version is not fully supported yet. Check :ref:`android` for
    more information about the current status.

Please note that Kivy is a framework. Installing Kivy itself on your phone will do
absolutely nothing. Kivy is not an application.

That said, we provide a "launcher" that allows you to push
your Kivy application onto your phone and execute it through a simple interface.
We'll provide instructions for packaging your Kivy application in a standalone
way in the future.

To install the Kivy launcher, you must:

#. Go to the `Kivy Launcher <https://market.android.com/details?id=org.kivy.pygame>`_
   on the Android market
#. Click on Install
#. Select your phone... And you're done!

Now, you can put your Kivy applications in the Kivy directory on the SD Card.
Refer to :ref:`android` for a more detailed explanation.

Installation of Examples
------------------------

.. warning::

    These examples are not final, they are just tests for the Kivy environment
    on Android.

#. Download the `KivyTest for Android <http://kivy.googlecode.com/files/kivytest-for-android.zip>`_
#. Unzip the content to the SD Card of your phone, in the kivy directory::

    /sdcard/kivy

#. Run the launcher and select Kivytest

